<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>EffectMonoToStereoFactory</name>
    <message>
        <location filename="../effectmonotostereofactory.cpp" line="29"/>
        <source>Mono to Stereo Converter Plugin</source>
        <translation>Engadido Conversor Mono a Stereo</translation>
    </message>
    <message>
        <location filename="../effectmonotostereofactory.cpp" line="48"/>
        <source>About Mono to Stereo Converter Plugin</source>
        <translation>Acerca do engadido Conversor de Mono a Stereo</translation>
    </message>
    <message>
        <location filename="../effectmonotostereofactory.cpp" line="49"/>
        <source>Qmmp Mono to Stereo Converter Plugin</source>
        <translation>Engadido conversor de Mono a Stereo Qmmp</translation>
    </message>
    <message>
        <location filename="../effectmonotostereofactory.cpp" line="50"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
